@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -224,6 +224,27 @@ class DatastreamAsyncClient:
         r"""Use this method to list connection profiles created
         in a project and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_list_connection_profiles():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.ListConnectionProfilesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_connection_profiles(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.ListConnectionProfilesRequest, dict]):
                 The request object.
@@ -302,6 +323,26 @@ class DatastreamAsyncClient:
         r"""Use this method to get details about a connection
         profile.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_get_connection_profile():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.GetConnectionProfileRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_connection_profile(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.GetConnectionProfileRequest, dict]):
                 The request object.
@@ -373,6 +414,39 @@ class DatastreamAsyncClient:
         r"""Use this method to create a connection profile in a
         project and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_create_connection_profile():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                connection_profile = datastream_v1alpha1.ConnectionProfile()
+                connection_profile.oracle_profile.hostname = "hostname_value"
+                connection_profile.oracle_profile.username = "username_value"
+                connection_profile.oracle_profile.password = "password_value"
+                connection_profile.oracle_profile.database_service = "database_service_value"
+                connection_profile.display_name = "display_name_value"
+
+                request = datastream_v1alpha1.CreateConnectionProfileRequest(
+                    parent="parent_value",
+                    connection_profile_id="connection_profile_id_value",
+                    connection_profile=connection_profile,
+                )
+
+                # Make the request
+                operation = client.create_connection_profile(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.CreateConnectionProfileRequest, dict]):
                 The request object.
@@ -473,6 +547,37 @@ class DatastreamAsyncClient:
         r"""Use this method to update the parameters of a
         connection profile.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_update_connection_profile():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                connection_profile = datastream_v1alpha1.ConnectionProfile()
+                connection_profile.oracle_profile.hostname = "hostname_value"
+                connection_profile.oracle_profile.username = "username_value"
+                connection_profile.oracle_profile.password = "password_value"
+                connection_profile.oracle_profile.database_service = "database_service_value"
+                connection_profile.display_name = "display_name_value"
+
+                request = datastream_v1alpha1.UpdateConnectionProfileRequest(
+                    connection_profile=connection_profile,
+                )
+
+                # Make the request
+                operation = client.update_connection_profile(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.UpdateConnectionProfileRequest, dict]):
                 The request object.
@@ -569,6 +674,29 @@ class DatastreamAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Use this method to delete a connection profile..
 
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_delete_connection_profile():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.DeleteConnectionProfileRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_connection_profile(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.DeleteConnectionProfileRequest, dict]):
                 The request object.
@@ -663,6 +791,35 @@ class DatastreamAsyncClient:
         returns children data objects under a parent data object
         that's optionally supplied in the request.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_discover_connection_profile():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                connection_profile = datastream_v1alpha1.ConnectionProfile()
+                connection_profile.oracle_profile.hostname = "hostname_value"
+                connection_profile.oracle_profile.username = "username_value"
+                connection_profile.oracle_profile.password = "password_value"
+                connection_profile.oracle_profile.database_service = "database_service_value"
+                connection_profile.display_name = "display_name_value"
+
+                request = datastream_v1alpha1.DiscoverConnectionProfileRequest(
+                    connection_profile=connection_profile,
+                    recursive=True,
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.discover_connection_profile(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.DiscoverConnectionProfileRequest, dict]):
                 The request object. Request message for 'discover'
@@ -712,6 +869,27 @@ class DatastreamAsyncClient:
         r"""Use this method to list streams in a project and
         location.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_list_streams():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.ListStreamsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_streams(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.ListStreamsRequest, dict]):
                 The request object.
@@ -789,6 +967,25 @@ class DatastreamAsyncClient:
     ) -> datastream_resources.Stream:
         r"""Use this method to get details about a stream.
 
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_get_stream():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.GetStreamRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_stream(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.GetStreamRequest, dict]):
                 The request object.
@@ -859,6 +1056,36 @@ class DatastreamAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Use this method to create a stream.
 
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_create_stream():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                stream = datastream_v1alpha1.Stream()
+                stream.display_name = "display_name_value"
+                stream.source_config.source_connection_profile_name = "source_connection_profile_name_value"
+                stream.destination_config.destination_connection_profile_name = "destination_connection_profile_name_value"
+
+                request = datastream_v1alpha1.CreateStreamRequest(
+                    parent="parent_value",
+                    stream_id="stream_id_value",
+                    stream=stream,
+                )
+
+                # Make the request
+                operation = client.create_stream(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.CreateStreamRequest, dict]):
                 The request object.
@@ -957,6 +1184,35 @@ class DatastreamAsyncClient:
         r"""Use this method to update the configuration of a
         stream.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_update_stream():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                stream = datastream_v1alpha1.Stream()
+                stream.display_name = "display_name_value"
+                stream.source_config.source_connection_profile_name = "source_connection_profile_name_value"
+                stream.destination_config.destination_connection_profile_name = "destination_connection_profile_name_value"
+
+                request = datastream_v1alpha1.UpdateStreamRequest(
+                    stream=stream,
+                )
+
+                # Make the request
+                operation = client.update_stream(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.UpdateStreamRequest, dict]):
                 The request object.
@@ -1052,6 +1308,29 @@ class DatastreamAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Use this method to delete a stream.
 
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_delete_stream():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.DeleteStreamRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_stream(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.DeleteStreamRequest, dict]):
                 The request object.
@@ -1143,6 +1422,29 @@ class DatastreamAsyncClient:
         r"""Use this method to fetch any errors associated with a
         stream.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_fetch_errors():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.FetchErrorsRequest(
+                )
+
+                # Make the request
+                operation = client.fetch_errors(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.FetchErrorsRequest, dict]):
                 The request object. Request message for 'FetchErrors'
@@ -1207,6 +1509,27 @@ class DatastreamAsyncClient:
         children data objects under a parent data object that's
         optionally supplied in the request.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_fetch_static_ips():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.FetchStaticIpsRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                page_result = client.fetch_static_ips(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.FetchStaticIpsRequest, dict]):
                 The request object. Request message for 'FetchStaticIps'
@@ -1290,6 +1613,35 @@ class DatastreamAsyncClient:
         r"""Use this method to create a private connectivity
         configuration.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_create_private_connection():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                private_connection = datastream_v1alpha1.PrivateConnection()
+                private_connection.display_name = "display_name_value"
+
+                request = datastream_v1alpha1.CreatePrivateConnectionRequest(
+                    parent="parent_value",
+                    private_connection_id="private_connection_id_value",
+                    private_connection=private_connection,
+                )
+
+                # Make the request
+                operation = client.create_private_connection(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.CreatePrivateConnectionRequest, dict]):
                 The request object.
@@ -1389,6 +1741,26 @@ class DatastreamAsyncClient:
         r"""Use this method to get details about a private
         connectivity configuration.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_get_private_connection():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.GetPrivateConnectionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_private_connection(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.GetPrivateConnectionRequest, dict]):
                 The request object.
@@ -1462,6 +1834,27 @@ class DatastreamAsyncClient:
         r"""Use this method to list private connectivity
         configurations in a project and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_list_private_connections():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.ListPrivateConnectionsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_private_connections(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.ListPrivateConnectionsRequest, dict]):
                 The request object.
@@ -1541,6 +1934,30 @@ class DatastreamAsyncClient:
         r"""Use this method to delete a private connectivity
         configuration.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_delete_private_connection():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.DeletePrivateConnectionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_private_connection(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.DeletePrivateConnectionRequest, dict]):
                 The request object.
@@ -1635,6 +2052,36 @@ class DatastreamAsyncClient:
         r"""Use this method to create a route for a private
         connectivity in a project and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_create_route():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                route = datastream_v1alpha1.Route()
+                route.display_name = "display_name_value"
+                route.destination_address = "destination_address_value"
+
+                request = datastream_v1alpha1.CreateRouteRequest(
+                    parent="parent_value",
+                    route_id="route_id_value",
+                    route=route,
+                )
+
+                # Make the request
+                operation = client.create_route(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.CreateRouteRequest, dict]):
                 The request object. route creation request
@@ -1732,6 +2179,25 @@ class DatastreamAsyncClient:
     ) -> datastream_resources.Route:
         r"""Use this method to get details about a route.
 
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_get_route():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.GetRouteRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_route(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.GetRouteRequest, dict]):
                 The request object. route get request
@@ -1805,6 +2271,27 @@ class DatastreamAsyncClient:
         r"""Use this method to list routes created for a private
         connectivity in a project and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_list_routes():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.ListRoutesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_routes(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.ListRoutesRequest, dict]):
                 The request object. route list request
@@ -1883,6 +2370,29 @@ class DatastreamAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Use this method to delete a route.
 
+        .. code-block:: python
+
+            from google.cloud import datastream_v1alpha1
+
+            def sample_delete_route():
+                # Create a client
+                client = datastream_v1alpha1.DatastreamClient()
+
+                # Initialize request argument(s)
+                request = datastream_v1alpha1.DeleteRouteRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_route(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.datastream_v1alpha1.types.DeleteRouteRequest, dict]):
                 The request object. route deletion request
